/*******************************************************************
 *
 * Copyright  1998, Bachmann Software and Services.
 * All rights reserved.
 *
 * FileName:
 *		PrintMgrDefines.h
 *
 * Description:
 *		Print Manager library private definitions.
 *
 * History:
 *   	12/14/98    Greg Winton    Created file.
 *
 *    12/23/98    Greg Winton    Added PrnDrawText... defines.
 *
 *******************************************************************/


#ifndef __PRINT_MGR_DEFINES_H__
#define __PRINT_MGR_DEFINES_H__

// PalmPilot common definitions
#include <Common.h>

/************************************************************
 * Sample Library result codes
 * (appErrorClass is reserved for 3rd party apps/libraries.
 * It is defined in SystemMgr.h)
 *************************************************************/

#define prnErrParam			(appErrorClass | 1)		// invalid parameter
#define prnErrNotOpen		(appErrorClass | 2)		// library is not open
#define prnErrAlreadyOpen  (appErrorClass | 3)     // return from PrnOpen() if
                                                   // the library is already open by others
#define prnErrStillOpen		(appErrorClass | 4)		// returned from PrnClose() if
																	// the library is still open by others
#define prnErrMemory			(appErrorClass | 5)		// memory error occurred
#define prnErrDevice       (appErrorClass | 6)     // device not ready error
#define prnErrPort         (appErrorClass | 7)     // port error occurred
#define prnErrAbort        (appErrorClass | 8)     // user aborted
#define prnErrNotImpl      (appErrorClass | 9)     // function not implemented
#define prnErrNotSupp      (appErrorClass | 10)    // request not supported.
#define prnErrState        (appErrorClass | 11)    // state error

/********************************************************************
 * Type and creator of Sample Library database
 ********************************************************************/
#define		printMgrCreatorID	'BPM1'               // Bachmann Print Manager database creator
#define		printMgrTypeID		'libr'               // Standard library database type

/********************************************************************
 * Internal library name which can be passed to SysLibFind()
 ********************************************************************/
#define		printMgrName			"Print Manager"

/********************************************************************
 * Public Structures
 ********************************************************************/

// Max font typeface length.
#define prnFontMaxTypeface (25)

typedef struct {
   Char           typeface [prnFontMaxTypeface+1];
   UInt           height;
   Boolean        bold;
   Boolean        italics;
   } PrnFontType;

typedef PrnFontType* PrnFontPtr;

typedef enum {
   prnOrientPortrait = 0,
   prnOrientLandscape
   } PrnOrientEnum;

#define prnDrawTextLeft         (0x0001)
#define prnDrawTextCenter       (0x0002)
#define prnDrawTextRight        (0x0004)
#define prnDrawTextBottom       (0x0010)
#define prnDrawTextVCenter      (0x0020)
#define prnDrawTextTop          (0x0040)
#define prnDrawTextSingleLine   (0x0100)
#define prnDrawTextMultiLine    (0x0200)
#define prnDrawTextWordBreak    (0x0400)
#define prnDrawTextClip         (0x1000)
#define prnDrawTextNoClip       (0x2000)

#define prnDrawTextHorzAlignMask    (0x000F)
#define prnDrawTextVertAlignMask    (0x00F0)
#define prnDrawTextLineFormatMask   (0x0F00)
#define prnDrawTextClippingMask     (0xF000)



typedef enum {
   prnPaperTypeRoll = 0,
   prnPaperTypeLetter,
   prnPaperTypeA4,
   prnPaperTypeLegal

   } PrnPaperTypeEnum;


#define  BPMSettings_FILE_CREATOR   ('BPMC')
#define  BPMSettings_FILE_VERSION   (0x01)
#define  BPMSettings_PREF_ID        (0x02)
#define  BPMSettings_PREF_VERSION   (0x01)


#define  MAXSIZE_DRIVERNAME         25

#endif	// __PRINT_MGR_DEFINES_H__
