#include "pms_main.h"
#include "form.h"

/*
   SampleForm:
   Prints out a dummy form. 
   Parms:	formP					Parent form.
   Return:	0						Success.
			-1						Error.
*/

void
SampleForm (FormPtr formP)
{
   UInt err;
   UInt refNum = 0;


   // Load the library 
   err = SampleLoad(formP, PrintManager);
  
   
   // Make sure refNum is not 0 (we should not be here if it is).
   refNum = MainFormGetRefNum (formP);
   ErrFatalDisplayIf ((refNum == 0), "Invalid state!");


   // Open the printer
   err = SampleOpen(formP, PrintManager); 
   ErrFatalDisplayIf ((err != 0), "Could not open printer");

   // Set the settings
   SampleSettings(formP, PrintManager);

   // Print the text
   SamplePrintForm( formP);

   // Close printer
   SampleClose(formP, PrintManager);

   // Unload the library
   SampleUnload(formP);
   

}



/*
   SamplePrintForm:
   Handles the dirty work, the text and lines 
   Parms:	formP					Parent form.
   Return:	0						Success.
			-1						Error.
*/

void
SamplePrintForm (FormPtr formP)
{
   UInt refNum;
   PrnFontType font;
   RectangleType r;

   
   refNum = MainFormGetRefNum (formP);
   ErrFatalDisplayIf ((refNum == 0), "Invalid state!");
   
   // Set font to Times Roman 14 bold.
   StrCopy (font.typeface, "Times Roman");
   font.height = 12;
   font.bold = true;
   font.italics = false;
   PrnSetFont (refNum, &font);   
   

   
   // Begin Printing

   // Paint Title Box (frame).
   r.topLeft.x = 538;						
   r.topLeft.y = 0;							
   r.extent.x = 1275;						
   r.extent.y = 175;						
   PrnDrawRectangleFrame (refNum, &r);      
   PrnDrawText(refNum, "TimeSheet for Josh Karlin", StrLen("TimeSheet for Josh Karlin"), &r, prnDrawTextCenter | prnDrawTextVCenter);

   // Paint Customer Info TitleBox (frame).
   r.topLeft.x = 309;						
   r.topLeft.y = 315;							
   r.extent.x = 402;						
   r.extent.y = 60;						
   PrnDrawRectangleFrame (refNum, &r);      
   PrnDrawText(refNum, "Customer Info", StrLen("Customer Info"), &r, prnDrawTextCenter | prnDrawTextCenter);


   // Paint Customer Rectangle (frame).
   r.topLeft.x = 0;						
   r.topLeft.y = 375;							
   r.extent.x = 1000;						
   r.extent.y = 600;						
   PrnDrawRectangleFrame (refNum, &r);      


   PrnDrawChars(refNum, "Name:", StrLen("Name:"), 100, 475);
   PrnDrawLine(refNum, 309, 525, 866, 525);
   PrnDrawChars(refNum, "John Davis", StrLen("John Davis"), 309, 475);

   PrnDrawChars(refNum, "Street:", StrLen("Street:"), 100, 575);
   PrnDrawLine(refNum, 309, 625, 866, 625);
   PrnDrawChars(refNum, "26 Wickham Ave", StrLen("26 Wichkham Ave"), 309, 575);

   PrnDrawChars(refNum, "City:", StrLen("City:"), 100, 675);
   PrnDrawLine(refNum, 309, 725, 866, 725);
   PrnDrawChars(refNum, "New York", StrLen("New York"), 309, 675);

   PrnDrawChars(refNum, "Zip:", StrLen("Zip:"), 100, 775);
   PrnDrawLine(refNum, 309, 825, 866, 825);
   PrnDrawChars(refNum, "12441", StrLen("12441"), 309, 775);


   // Paint Employee Info TitleBox (frame).
   r.topLeft.x = 1659;						
   r.topLeft.y = 315;							
   r.extent.x = 402;						
   r.extent.y = 60;						
   PrnDrawRectangleFrame (refNum, &r);      
   PrnDrawText(refNum, "Employee Info", StrLen("Employee Info"), &r, prnDrawTextCenter | prnDrawTextVCenter);


   // Paint Employee Info Rectangle (frame).
   r.topLeft.x = 1350;						
   r.topLeft.y = 375;							
   r.extent.x = 1000;						
   r.extent.y = 600;						
   PrnDrawRectangleFrame (refNum, &r);      


   PrnDrawChars(refNum, "Name:", StrLen("Name:"), 1450, 475);
   PrnDrawLine(refNum, 1759, 525, 2316, 525);
   PrnDrawChars(refNum, "Jim Burrow", StrLen("Jim Burrow"), 1759, 475);

   PrnDrawChars(refNum, "ID:", StrLen("ID:"), 1450, 575);
   PrnDrawLine(refNum, 1759, 625, 2316, 625);
   PrnDrawChars(refNum, "321232123", StrLen("321232123"), 1759, 575);

   PrnDrawChars(refNum, "Branch:", StrLen("Branch:"), 1450, 675);
   PrnDrawLine(refNum, 1759, 725, 2316, 725);
   PrnDrawChars(refNum, "SouthWestern", StrLen("SouthWestern"), 1759, 675);

   PrnDrawChars(refNum, "Signature:", StrLen("Signature:"), 1450, 775);
   PrnDrawLine(refNum, 1759, 825, 2316, 825);
   



   // Paint Job Type TitleBox (frame).
   r.topLeft.x = 209;						
   r.topLeft.y = 1438;							
   r.extent.x = 402;						
   r.extent.y = 60;						
   PrnDrawRectangleFrame (refNum, &r);      
   PrnDrawText(refNum, "Job Type", StrLen("Job Type"), &r, prnDrawTextCenter | prnDrawTextVCenter);

   // Paint Job Type Rectangle (frame).
   r.topLeft.x = 0;					
   r.topLeft.y = 1498;							
   r.extent.x = 800;						
   r.extent.y = 380;						
   PrnDrawRectangleFrame (refNum, &r);      
   
   // Paint Job Type Rectangle->Software (Rectangle).
   r.topLeft.x = 100;						
   r.topLeft.y = 1558;							
   r.extent.x = 40;						
   r.extent.y = 40;						
   PrnDrawRectangle (refNum, &r, 0);       
   
   PrnDrawChars(refNum, "Software", StrLen("Software"), 180, 1558);

   // Paint Job Type Rectangle->Hardware (frame).
   r.topLeft.x = 100;						
   r.topLeft.y = 1650;							
   r.extent.x = 40;						
   r.extent.y = 40;						
   PrnDrawRectangleFrame (refNum, &r);         

   PrnDrawChars(refNum, "Hardware", StrLen("Hardware"), 180, 1650);

   // Paint Job Type Rectangle->Consulting (Rectangle).
   r.topLeft.x = 100;					
   r.topLeft.y = 1742;							
   r.extent.x = 40;					
   r.extent.y = 40;						
   PrnDrawRectangle (refNum, &r, 0);       
   
   PrnDrawChars(refNum, "Consulting", StrLen("Consulting"), 180, 1742);


   r.topLeft.x = 1350;
   r.topLeft.y = 1490;
   r.extent.x = 500;
   r.extent.y = 68;

   PrnDrawText(refNum, "Job Description", StrLen("Job Description"), &r, prnDrawTextLeft |prnDrawTextBottom);

   // Paint Job Description Line (line).
   PrnDrawLine(refNum, 1350, 1558, 1850, 1558);

   // Paint Job Description Line1 (line).
   PrnDrawLine(refNum, 1350, 1638, 2350, 1638);

   // Paint Job Description Line2 (line).
   PrnDrawLine(refNum, 1350, 1718, 2350, 1718);

   // Paint Job Description Line3 (line).
   PrnDrawLine(refNum, 1350, 1798, 2350, 1798);

   // Paint Job Description Line4 (line).
   PrnDrawLine(refNum, 1350, 1878, 2350, 1878);




   // Paint Time & Change TitleBox (frame).
   r.topLeft.x = 309;						
   r.topLeft.y = 2341;							
   r.extent.x = 402;						
   r.extent.y = 60;						
   PrnDrawRectangleFrame (refNum, &r);      
   PrnDrawText(refNum, "Time & Charge", StrLen("Time & Charge"), &r, prnDrawTextCenter | prnDrawTextVCenter);

   // Paint Time & Change Rectangle (frame).
   r.topLeft.x = 0;						
   r.topLeft.y = 2401;							
   r.extent.x = 1000;					
   r.extent.y = 380;						
   PrnDrawRectangleFrame (refNum, &r);     


   PrnDrawChars(refNum, "Hours:", StrLen("Hours:"), 100, 2438);
   PrnDrawLine(refNum, 309, 2488, 866, 2488);
   PrnDrawChars(refNum, "12", StrLen("12"), 309, 2438);


   PrnDrawChars(refNum, "Rate:", StrLen("Rate:"), 100, 2538);
   PrnDrawLine(refNum, 309, 2588, 866, 2588);
   PrnDrawChars(refNum, "45.00 p/hr", StrLen("45.00 p/hr"), 309, 2538);


   PrnDrawChars(refNum, "Total:", StrLen("Total:"), 100, 2638);
   PrnDrawLine(refNum, 309, 2688, 866, 2688);
   PrnDrawChars(refNum, "$540", StrLen("$540"), 309, 2638);


   // Set font to Courier 11 italic.
   StrCopy (font.typeface, "Courier");
   font.height = 11;
   font.bold = false;
   font.italics = true;
   PrnSetFont (refNum, &font);   

   PrnDrawChars(refNum, "I, John Davis, hereby acknowledge", StrLen("I, John Davis, hereby acknowledge"), 1350, 2438);
   PrnDrawChars(refNum, "and agree that, Don Johnson", StrLen("and agree that, Don Johnson"), 1350, 2488);
   PrnDrawChars(refNum, "completed his or her task", StrLen("completed his or her task"), 1350, 2538);
   PrnDrawChars(refNum, "profesionally, and will pay $540 for", StrLen("profesionally, and will pay $540 for"), 1350, 2588);
   PrnDrawChars(refNum, "his or her services.", StrLen("his or her services"), 1350,  2638);

   // Paint Signature Line (line).
   PrnDrawLine(refNum, 1350, 2781, 2350, 2781);

   r.topLeft.x = 1350;
   r.topLeft.y = 2781;
   r.extent.x = 1000;
   r.extent.y = 60;


   // Set font to Times Roman 10 bold.
   StrCopy (font.typeface, "Times Roman");
   font.height = 10;
   font.bold = true;
   font.italics = false;
   PrnSetFont (refNum, &font);   

   PrnDrawText(refNum, "Customer Signature", StrLen("Customer Signature"), &r, prnDrawTextCenter | prnDrawTextTop);

   PrnNewPage(refNum);
}