/*
   PMS_MAIN.CPP
   Main form handling functions.
   Copyright (c) Bachmann Software and Services, 1998
   Authors: Glenn Bachmann / Josh Karlin
*/

#include "pms_main.h"
#include "pms.h"
#include "pms_res.h"

#include "Email.h"
#include "doc.h"
#include "form.h"


const UInt linesPerPage = 55;




/*
   MainFormEventHandler:
   Parms:   pEvent   - event to be handled.
   Return:  true  - handled (successfully or not)
            false - not handled
*/
Boolean
MainFormEventHandler (EventPtr eventP)
{
   Boolean  handled = false;
   
   switch (eventP->eType)
   {
      case menuEvent:
      {
         FormPtr formP = FrmGetActiveForm ();
         handled = MainFormMenuHandler (formP, eventP);
         break;
      }
      
      case ctlSelectEvent:
      {
      // A control button was pressed.
         FormPtr formP = FrmGetActiveForm ();
         handled = MainFormButtonHandler (formP, eventP);
         break;
      }
      
      case frmOpenEvent:
      {
         FormPtr formP = FrmGetActiveForm ();

         FrmDrawForm (formP);
         handled = true;
         break;
      }
      
      default:
      {
         break;
      }
   }
   return handled;
}










/*
   MainFormButtonHandler:
   Handle a command sent to the main form.
   Parms:   formP    - form handling event.
            command  - command to be handled.
   Return:  true  - handled (successfully or not)
            false - not handled
*/
Boolean
MainFormMenuHandler (FormPtr /*formP*/, EventPtr eventP)
{
   Boolean handled = false;
   
   switch (eventP->data.menu.itemID)
   {
      default:
      {
         handled = false;
         break;
      }
   }
   return handled;
}

/*
   MainFormButtonHandler:
   Handle a command sent to the main form.
   Parms:   formP    - form handling event.
            eventP   - event to be handled.
   Return:  true  - handled (successfully or not)
            false - not handled
*/
Boolean
MainFormButtonHandler (FormPtr formP, EventPtr eventP)
{
   Boolean handled = false;
   
   switch (eventP->data.ctlEnter.controlID)
   {
      case MainEmailButton:   // User selected Email button.
      {
         SampleEmail (formP);
         handled = true;
         break;
      }



      case MainFormButton:   // User selected Form button.
      {
         SampleForm (formP);
         handled = true;
         break;
      }


   }
   return handled;
}







   
/*
   SampleLoad:
   Sample code for loading the PageMgr shared library.
   Parms:   formP                   Parent form.
   Return:  0                       Success.
            sysErrLibNotFound       PageMgr library not installed.
            sysErrNoFreeRAM         System error loading shared library.
            sysErrNoFreeLibSlots    System error loading shared library.
            pagErrAlreadyLoad       Library has already been loaded.
*/
Err
SampleLoad (FormPtr formP, BPMTypeEnum Type)
{
   // Declare text buffer for messages.
   Char  msg [80];
   UInt  msgSize = sizeof (msg);
   Err err;
   // PageMgr may only be loaded once, so we do not try
   // to find it first.  Already loaded is an error in this case.
   UInt refNum = 0;

   if ( Type == PageManager )
   {
		 err = SysLibLoad (pageMgrTypeID, pageMgrCreatorID, &refNum);
   }
   else if ( Type == PrintManager )
   {
		err = SysLibLoad(printMgrTypeID, printMgrCreatorID, &refNum);
   }

   // Check result of loading library.
   if (!err)
   {
   // PageMgr loaded successfully.
   
      // Store ref num.
      MainFormSetRefNum (formP, refNum);
      
      // Enable the appropriate controls.
    //  MainFormEnableControls (formP, pageMgrLoaded);
   }
   else
   {
   // Error loading PageMgr.

      // Notify user of error.
      StrPrintF (msg, "Error %i loading Printing Manager Library.", err);
      FrmCustomAlert (ErrorAlert, msg, NULL, NULL);
   }
   
   // Return result.
   return err;
}

/*
   SampleUnload:
   Unload the PageMgr library.
   Parms:   formP       Parent form.
   Return:  0           Success
*/
Err
SampleUnload (FormPtr formP)
{
   // Initialize result.
   Err err = 0;
   
   // Retrieve ref num for PageMgr library.
   UInt refNum = MainFormGetRefNum (formP);
   
   // Make sure refNum is not 0 (we should not be here if it is).
   ErrFatalDisplayIf ((refNum == 0), "Invalid state!");

   // Unload PageMgr library.
   err = SysLibRemove (refNum);

   // Update controls (we are back to unloaded state).
 //  MainFormEnableControls (formP, pageMgrUnloaded);
   
   // Return result.
   return err;
}

/*
   MainFormGetPrinter:
   Get the selected printer.
   Parms: formP      Form
          printer    outparam for printer name
          len        size of printer buffer
   Returns: none
*/

 void
MainFormGetPrinter (FormPtr formP, CharPtr printer, UInt len)
{
   Word index = FrmGetObjectIndex (formP, MainPrinterList);
   ListPtr listP = (ListPtr) FrmGetObjectPtr (formP, index);
   Word selectIndex = LstGetSelection (listP);
   CharPtr selectString = LstGetSelectionText (listP, selectIndex);

   StrNCopy (printer, selectString, len);
}


/*
   MainFormGetPort:
   Get the selected port type.
   Parms: formP		 Form
		  port	  	 outparam for port name
		  len		 size of port buffer
*/

 void
MainFormGetPort (FormPtr formP, CharPtr port, UInt len)
{
   Word index = FrmGetObjectIndex (formP, MainPortList);
   ListPtr listP = (ListPtr) FrmGetObjectPtr (formP, index);
   Word selectIndex = LstGetSelection (listP);
   CharPtr selectString = LstGetSelectionText (listP, selectIndex);

   StrNCopy (port, selectString, len);
}


/*
   SampleOpen:
   Sample code for opening the PageMgr shared library.
   Parms:   formP                   Parent form.
   Return:  0                       Success.
            pagErrAlreadyOpen       Library has already been loaded.
*/
Err
SampleOpen (FormPtr formP, BPMTypeEnum Type)
{
   Err err;
   char szPrinterType[50];
   char szPortType[50];
   
   // Get the Printer and Port types
   MainFormGetPrinter	( formP, szPrinterType, (UInt) sizeof(szPrinterType));
   MainFormGetPort		(formP,  szPortType, (UInt) sizeof(szPortType));
 
   // Declare text buffer for messages.
   Char  msg [80];
   UInt  msgSize = sizeof (msg);
   
   // Retrieve ref num for PageMgr shared library.
   UInt refNum = MainFormGetRefNum (formP);
   
   // Make sure refNum is not 0 (we should not be here if it is).
   ErrFatalDisplayIf ((refNum == 0), "Invalid state!");

   if ( Type == PageManager )
   {
	   // Open page manager.
	   err = PagOpen (refNum, szPrinterType, szPortType);
   }
   else if ( Type == PrintManager )
   {
	   // Open print manager.
	   err = PrnOpen (refNum, szPrinterType, szPortType);
   }
	   
	if (!err)
   {
   // Printing Mgr opened successfully.
   
      // Update controls.
     // MainFormEnableControls (formP, pageMgrOpened);
   }
   else
   {
   // Error opening Printing Mgr.

      // Notify user of error.
      StrPrintF (msg, "Error %i Opening Printing Mgr.", err);
      FrmCustomAlert (ErrorAlert, msg, NULL, NULL);
   }
   
   // Return result.
   return err;
}

/*
   SampleClose:
   Close the PageMgr library.
   Parms:   formP       Parent form.
   Return:  0           Success
*/
Err
SampleClose (FormPtr formP, BPMTypeEnum Type)
{
   // Initialize result.
   Err err = 0;
   
   // Retrieve ref num for PageMgr library.
   UInt refNum = MainFormGetRefNum (formP);
   
   // Check if ref num is valid.
   if (refNum)
   {
   // Ref num is valid.
   
	  if ( Type == PageManager )
	  {
		 // Close PageMgr.
		 PagClose (refNum);
	  }
	  else if ( Type == PrintManager )
	  {
		 // Close PrintMgr.
		 PrnClose(refNum);
	  }
      
      // Set result to success.
      err = 0;
   }
   else
   {
   // Ref num is not valid.
   
      // Set result to state error.
      err = pagErrState;
   }
   
   // Return result.
   return err;
}





/*
   SampleSettings:
   Set default settings for the print job - number of lines per page.
   Parms:   refNum      Library reference number.
   Return:  0           Success
*/
Err
SampleSettings (FormPtr formP, BPMTypeEnum Type)
{
   // Initialize error.
   Err err = 0;
   
   // Retrieve PageMgr reference number.
   UInt refNum = MainFormGetRefNum (formP);

   // Make sure refNum is not 0 (we should not be here if it is).
   ErrFatalDisplayIf ((refNum == 0), "Invalid state!");


   if ( Type == PageManager )
   {
	  // Set orientation to landscape.
	  PagSetOption (refNum, pagOptionMaxLines, linesPerPage);
   }
   else if ( Type == PrintManager )
   {

	  PrnSetOrientation(refNum, prnOrientPortrait);
   }

   // Return result.
   return err;
}


   
UInt
MainFormGetRefNum (FormPtr formP)
{
   // Get gadget index on form.
   Word gadgetIndex = FrmGetObjectIndex (formP, MainDataGadget);
   
   // Retrieve data associated with gadget.
   VoidPtr dataP = FrmGetGadgetData (formP, gadgetIndex);
   
   // Cast data pointer to UInt.
   UInt refNum = (UInt)dataP;
   
   return refNum;
}

void
MainFormSetRefNum (FormPtr formP, UInt refNum)
{
   // Get gadget index on form.
   Word gadgetIndex = FrmGetObjectIndex (formP, MainDataGadget);
   
   // Cast ref num to data pointer.
   VoidPtr dataP = (VoidPtr) refNum;
   
   // Set data associated with gadget.
   FrmSetGadgetData (formP, gadgetIndex, dataP);
}




